Class: Aws::DSQL::Types::KinesisTargetDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::DSQL::Types::KinesisTargetDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dsql/types.rb
Overview
Kinesis stream target configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#role_arn ⇒ String
The ARN of the IAM role that grants permission to write to the Kinesis stream.
-
#stream_arn ⇒ String
The ARN of the Kinesis stream.
Instance Attribute Details
#role_arn ⇒ String
The ARN of the IAM role that grants permission to write to the Kinesis stream. This can be a standard role (‘arn:aws:iam::account-id:role/role-name`) or a role with a path prefix (`arn:aws:iam::account-id:role/service-role/role-name`), such as roles auto-created by the console.
701 702 703 704 705 706 |
# File 'lib/aws-sdk-dsql/types.rb', line 701 class KinesisTargetDefinition < Struct.new( :stream_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the Kinesis stream.
701 702 703 704 705 706 |
# File 'lib/aws-sdk-dsql/types.rb', line 701 class KinesisTargetDefinition < Struct.new( :stream_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |