Class: Aws::DSQL::Types::ListClustersInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dsql/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.

Returns:

  • (Integer)


722
723
724
725
726
727
# File 'lib/aws-sdk-dsql/types.rb', line 722

class ListClustersInput < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your initial ListClusters operation returns a nextToken, you can include the returned nextToken in following ListClusters operations, which returns results in the next page.

Returns:

  • (String)


722
723
724
725
726
727
# File 'lib/aws-sdk-dsql/types.rb', line 722

class ListClustersInput < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end