Class: Aws::DSQL::Types::ListStreamsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DSQL::Types::ListStreamsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dsql/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If nextToken is returned, there are more results available.
-
#streams ⇒ Array<Types::StreamSummary>
An array of the returned streams.
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, make the call again using the returned token.
788 789 790 791 792 793 |
# File 'lib/aws-sdk-dsql/types.rb', line 788 class ListStreamsOutput < Struct.new( :next_token, :streams) SENSITIVE = [] include Aws::Structure end |
#streams ⇒ Array<Types::StreamSummary>
An array of the returned streams.
788 789 790 791 792 793 |
# File 'lib/aws-sdk-dsql/types.rb', line 788 class ListStreamsOutput < Struct.new( :next_token, :streams) SENSITIVE = [] include Aws::Structure end |