Class: Aws::DSQL::Types::UpdateClusterInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-dsql/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully. The subsequent retries with the same client token return the result from the original successful request and they have no additional effect.

If you don't specify a client token, the Amazon Web Services SDK automatically generates one.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
# File 'lib/aws-sdk-dsql/types.rb', line 1131

class UpdateClusterInput < Struct.new(
  :identifier,
  :deletion_protection_enabled,
  :kms_encryption_key,
  :client_token,
  :multi_region_properties)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

Specifies whether to enable deletion protection in your cluster.

Returns:

  • (Boolean)


1131
1132
1133
1134
1135
1136
1137
1138
1139
# File 'lib/aws-sdk-dsql/types.rb', line 1131

class UpdateClusterInput < Struct.new(
  :identifier,
  :deletion_protection_enabled,
  :kms_encryption_key,
  :client_token,
  :multi_region_properties)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The ID of the cluster you want to update.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
# File 'lib/aws-sdk-dsql/types.rb', line 1131

class UpdateClusterInput < Struct.new(
  :identifier,
  :deletion_protection_enabled,
  :kms_encryption_key,
  :client_token,
  :multi_region_properties)
  SENSITIVE = []
  include Aws::Structure
end

#kms_encryption_keyString

The KMS key that encrypts and protects the data on your cluster. You can specify the ARN, ID, or alias of an existing key or have Amazon Web Services create a default key for you.

To switch to the key owned by Amazon Web Services, specify the reserved value AWS_OWNED_KMS_KEY.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
1138
1139
# File 'lib/aws-sdk-dsql/types.rb', line 1131

class UpdateClusterInput < Struct.new(
  :identifier,
  :deletion_protection_enabled,
  :kms_encryption_key,
  :client_token,
  :multi_region_properties)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_propertiesTypes::MultiRegionProperties

The new multi-Region cluster configuration settings to be applied during an update operation.



1131
1132
1133
1134
1135
1136
1137
1138
1139
# File 'lib/aws-sdk-dsql/types.rb', line 1131

class UpdateClusterInput < Struct.new(
  :identifier,
  :deletion_protection_enabled,
  :kms_encryption_key,
  :client_token,
  :multi_region_properties)
  SENSITIVE = []
  include Aws::Structure
end