Class: Aws::DSQL::Waiters::ClusterNotExists
- Inherits:
-
Object
- Object
- Aws::DSQL::Waiters::ClusterNotExists
- Defined in:
- lib/aws-sdk-dsql/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Cluster is gone
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ClusterNotExists
constructor
A new instance of ClusterNotExists.
-
#wait(params = {}) ⇒ Types::GetClusterOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ClusterNotExists
Returns a new instance of ClusterNotExists.
125 126 |
# File 'lib/aws-sdk-dsql/waiters.rb', line 125
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
148 149 150 |
# File 'lib/aws-sdk-dsql/waiters.rb', line 148 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetClusterOutput
Returns a response object which responds to the following methods:
- #identifier => String
- #arn => String
- #status => String
- #creation_time => Time
- #deletion_protection_enabled => Boolean
- #multi_region_properties => Types::MultiRegionProperties
- #tags => Hash<String,String>
- #encryption_details => Types::EncryptionDetails
- #endpoint => String
143 |
# File 'lib/aws-sdk-dsql/waiters.rb', line 143
def wait: (
|