Class: Aws::DSQL::Waiters::StreamActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-dsql/waiters.rb,
sig/waiters.rbs

Overview

Wait until a Stream is ACTIVE

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StreamActive

Returns a new instance of StreamActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


161
162
# File 'lib/aws-sdk-dsql/waiters.rb', line 161

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



185
186
187
# File 'lib/aws-sdk-dsql/waiters.rb', line 185

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetStreamOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :cluster_identifier (required, String)

    The ID of the cluster containing the stream to retrieve.

  • :stream_identifier (required, String)

    The ID of the stream to retrieve.

Returns:



180
# File 'lib/aws-sdk-dsql/waiters.rb', line 180

def wait: (