Class: Aws::DSQL::Types::ListStreamsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DSQL::Types::ListStreamsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dsql/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The ID of the cluster for which to list streams.
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial ListStreams operation returns a nextToken, you can include the returned nextToken in following ListStreams operations, which returns results in the next page.
Instance Attribute Details
#cluster_identifier ⇒ String
The ID of the cluster for which to list streams.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-dsql/types.rb', line 767 class ListStreamsInput < Struct.new( :cluster_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results. Default: 10.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-dsql/types.rb', line 767 class ListStreamsInput < Struct.new( :cluster_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListStreams operation returns a nextToken, you can include the returned nextToken in following ListStreams operations, which returns results in the next page.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-dsql/types.rb', line 767 class ListStreamsInput < Struct.new( :cluster_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |